@@ -17,28 +17,34 @@ import json
 
 import mock
 
+from sushy import auth
 from sushy import connector
-from sushy import exceptions
 from sushy import main
 from sushy.resources.manager import manager
+from sushy.resources.sessionservice import session
+from sushy.resources.sessionservice import sessionservice
 from sushy.resources.system import system
 from sushy.tests.unit import base
 
 
 class MainTestCase(base.TestCase):
 
+    @mock.patch.object(auth, 'SessionOrBasicAuth', autospec=True)
     @mock.patch.object(connector, 'Connector', autospec=True)
-    def setUp(self, mock_connector):
+    @mock.patch.object(sessionservice, 'SessionService', autospec=True)
+    def setUp(self, mock_session_service, mock_connector, mock_auth):
         super(MainTestCase, self).setUp()
         self.conn = mock.Mock()
+        self.sess_serv = mock.Mock()
+        self.sess_serv.create_session.return_value = (None, None)
+        mock_session_service.return_value = self.sess_serv
         mock_connector.return_value = self.conn
         with open('sushy/tests/unit/json_samples/root.json', 'r') as f:
             self.conn.get.return_value.json.return_value = json.loads(f.read())
-        self.root = main.Sushy(
-            'http://foo.bar:1234', username='foo', password='bar',
-            verify=True)
+        self.root = main.Sushy('http://foo.bar:1234',
+                               verify=True, auth=mock_auth)
         mock_connector.assert_called_once_with(
-            'http://foo.bar:1234', 'foo', 'bar', True)
+            'http://foo.bar:1234', True)
 
     def test__parse_attributes(self):
         self.root._parse_attributes()
@@ -49,6 +55,26 @@ class MainTestCase(base.TestCase):
                          self.root.uuid)
         self.assertEqual('/redfish/v1/Systems', self.root._systems_path)
         self.assertEqual('/redfish/v1/Managers', self.root._managers_path)
+        self.assertEqual('/redfish/v1/SessionService',
+                         self.root._session_service_path)
+
+    @mock.patch.object(connector, 'Connector', autospec=True)
+    def test__init_throws_exception(self, mock_Connector):
+        self.assertRaises(
+            ValueError, main.Sushy, 'http://foo.bar:1234',
+            'foo', 'bar', auth=mock.MagicMock())
+
+    @mock.patch.object(connector, 'Connector', autospec=True)
+    def test_custom_connector(self, mock_Sushy_Connector):
+        connector_mock = mock.MagicMock()
+        with open('sushy/tests/unit/json_samples/root.json', 'r') as f:
+            connector_mock.get.return_value.json.return_value = (
+                json.loads(f.read()))
+        main.Sushy('http://foo.bar:1234', 'foo', 'bar',
+                   connector=connector_mock)
+        self.assertTrue(connector_mock.post.called)
+        self.assertTrue(connector_mock.get.called)
+        self.assertFalse(mock_Sushy_Connector.called)
 
     @mock.patch.object(system, 'SystemCollection', autospec=True)
     def test_get_system_collection(self, mock_system_collection):
@@ -78,25 +104,16 @@ class MainTestCase(base.TestCase):
             self.root._conn, 'fake-manager-id',
             redfish_version=self.root.redfish_version)
 
+    @mock.patch.object(sessionservice, 'SessionService', autospec=True)
+    def test_get_sessionservice(self, mock_sess_serv):
+        self.root.get_session_service()
+        mock_sess_serv.assert_called_once_with(
+            self.root._conn, '/redfish/v1/SessionService',
+            redfish_version=self.root.redfish_version)
 
-class BareMinimumMainTestCase(base.TestCase):
-
-    @mock.patch.object(connector, 'Connector', autospec=True)
-    def setUp(self, mock_connector):
-        super(BareMinimumMainTestCase, self).setUp()
-        self.conn = mock.Mock()
-        mock_connector.return_value = self.conn
-        with open('sushy/tests/unit/json_samples/'
-                  'bare_minimum_root.json', 'r') as f:
-            self.conn.get.return_value.json.return_value = json.loads(f.read())
-        self.root = main.Sushy('http://foo.bar:1234', verify=True)
-
-    def test_get_system_collection_when_systems_attr_absent(self):
-        self.assertRaisesRegex(
-            exceptions.MissingAttributeError,
-            'Systems/@odata.id', self.root.get_system_collection)
-
-    def test_get_manager_collection_when_managers_attr_absent(self):
-        self.assertRaisesRegex(
-            exceptions.MissingAttributeError,
-            'Managers/@odata.id', self.root.get_manager_collection)
+    @mock.patch.object(session, 'Session', autospec=True)
+    def test_get_session(self, mock_sess):
+        self.root.get_session('asdf')
+        mock_sess.assert_called_once_with(
+            self.root._conn, 'asdf',
+            redfish_version=self.root.redfish_version)
